# coding: utf-8

"""
Earnix Elevate Import Export API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from __future__ import annotations

import json
import pprint
from typing import Optional

from pydantic.v1 import Field, constr

from earnix_elevate.clients.imx.models.create_connection_request import (
    CreateConnectionRequest,
)
from earnix_elevate.clients.imx.models.snowflake_auth_request import (
    SnowflakeAuthRequest,
)


class CreateSnowflakeConnectionRequest(CreateConnectionRequest):
    """
    `CreateSnowflakeConnectionRequest`

    Request to create a Snowflake Connection for accessing Snowflake data warehouse. Requires authentication credentials and connection settings including database, schema, and warehouse configuration.
    """

    auth: SnowflakeAuthRequest = Field(...)
    database: Optional[constr(strict=True, max_length=500)] = Field(
        default=None, description="The Snowflake database to connect to"
    )
    var_schema: Optional[constr(strict=True, max_length=500)] = Field(
        default=None, alias="schema", description="The Snowflake schema to use"
    )
    warehouse: Optional[constr(strict=True, max_length=500)] = Field(
        default=None, description="The Snowflake warehouse to use for query execution"
    )
    __properties = [
        "name",
        "description",
        "tags",
        "type",
        "database",
        "schema",
        "warehouse",
    ]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CreateSnowflakeConnectionRequest:
        """Create an instance of CreateSnowflakeConnectionRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # set to None if description (nullable) is None
        # and __fields_set__ contains the field
        if self.description is None and "description" in self.__fields_set__:
            _dict["description"] = None

        # set to None if database (nullable) is None
        # and __fields_set__ contains the field
        if self.database is None and "database" in self.__fields_set__:
            _dict["database"] = None

        # set to None if var_schema (nullable) is None
        # and __fields_set__ contains the field
        if self.var_schema is None and "var_schema" in self.__fields_set__:
            _dict["schema"] = None

        # set to None if warehouse (nullable) is None
        # and __fields_set__ contains the field
        if self.warehouse is None and "warehouse" in self.__fields_set__:
            _dict["warehouse"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CreateSnowflakeConnectionRequest:
        """Create an instance of CreateSnowflakeConnectionRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CreateSnowflakeConnectionRequest.parse_obj(obj)

        _obj = CreateSnowflakeConnectionRequest.parse_obj(
            {
                "name": obj.get("name"),
                "description": obj.get("description"),
                "tags": obj.get("tags"),
                "type": obj.get("type"),
                "database": obj.get("database"),
                "var_schema": obj.get("schema"),
                "warehouse": obj.get("warehouse"),
            }
        )
        return _obj



# coding: utf-8

"""
Earnix Elevate Import Export API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from __future__ import annotations

import json
import pprint
from typing import Optional

from pydantic.v1 import BaseModel, Field, StrictStr


class TableDetailsResponse(BaseModel):
    """
    `TableDetailsResponse`

    Response containing details about a database table including its name, database, and schema information.
    """

    name: Optional[StrictStr] = Field(default=None, description="The name of the table")
    database: Optional[StrictStr] = Field(
        default=None, description="The database containing the table"
    )
    var_schema: Optional[StrictStr] = Field(
        default=None, alias="schema", description="The schema containing the table"
    )
    __properties = ["name", "database", "schema"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> TableDetailsResponse:
        """Create an instance of TableDetailsResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> TableDetailsResponse:
        """Create an instance of TableDetailsResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return TableDetailsResponse.parse_obj(obj)

        _obj = TableDetailsResponse.parse_obj(
            {
                "name": obj.get("name"),
                "database": obj.get("database"),
                "var_schema": obj.get("schema"),
            }
        )
        return _obj



# coding: utf-8

"""
Earnix Elevate Data API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from __future__ import annotations

import json
import pprint
from typing import Optional

from pydantic.v1 import BaseModel, Field, StrictStr, conlist

from earnix_elevate.clients.data.models.export_part_result_pair_response import (
    ExportPartResultPairResponse,
)


class ExportS3PartJobStatusResponse(BaseModel):
    """
    `ExportS3PartJobStatusResponse`

    Export S3 part job status response
    """

    status: Optional[StrictStr] = Field(
        default=None,
        description="Current status of the multi-part export job (e.g., PENDING, IN_PROGRESS, COMPLETED, FAILED)",
    )
    error: Optional[StrictStr] = Field(
        default=None,
        description="Error message if the export job failed, null if successful",
    )
    result: Optional[conlist(ExportPartResultPairResponse)] = Field(
        default=None,
        description="List of upload results for each part of the multi-part export, containing ETags and part numbers",
    )
    __properties = ["status", "error", "result"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ExportS3PartJobStatusResponse:
        """Create an instance of ExportS3PartJobStatusResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in result (list)
        _items = []
        if self.result:
            for _item in self.result:
                if _item:
                    _items.append(_item.to_dict())
            _dict["result"] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ExportS3PartJobStatusResponse:
        """Create an instance of ExportS3PartJobStatusResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ExportS3PartJobStatusResponse.parse_obj(obj)

        _obj = ExportS3PartJobStatusResponse.parse_obj(
            {
                "status": obj.get("status"),
                "error": obj.get("error"),
                "result": [
                    ExportPartResultPairResponse.from_dict(_item)
                    for _item in obj.get("result")
                ]
                if obj.get("result") is not None
                else None,
            }
        )
        return _obj



# coding: utf-8

"""
Earnix Elevate Import Export API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from __future__ import annotations

import json
import pprint
from datetime import datetime
from typing import Optional

from pydantic.v1 import Field, StrictStr

from earnix_elevate.clients.imx.models.delta_sharing_auth_response import (
    DeltaSharingAuthResponse,
)


class DeltaSharingJsonProfileAuthResponse(DeltaSharingAuthResponse):
    """
    `DeltaSharingJsonProfileAuthResponse`

    Delta Sharing connection authentication response using json profile.
    """

    delta_sharing_profile_name: Optional[StrictStr] = Field(
        default=None,
        alias="deltaSharingProfileName",
        description="The name of Delta Sharing profile configuration.",
    )
    shared_data_endpoint: Optional[StrictStr] = Field(
        default=None,
        alias="sharedDataEndpoint",
        description="The endpoint URL for accessing shared data in DeltaSharing.",
    )
    token_expiration_time: Optional[datetime] = Field(
        default=None,
        alias="tokenExpirationTime",
        description="The expiration timestamp of the authentication token.",
    )
    __properties = [
        "authType",
        "deltaSharingProfileName",
        "sharedDataEndpoint",
        "tokenExpirationTime",
    ]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> DeltaSharingJsonProfileAuthResponse:
        """Create an instance of DeltaSharingJsonProfileAuthResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> DeltaSharingJsonProfileAuthResponse:
        """Create an instance of DeltaSharingJsonProfileAuthResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return DeltaSharingJsonProfileAuthResponse.parse_obj(obj)

        _obj = DeltaSharingJsonProfileAuthResponse.parse_obj(
            {
                "auth_type": obj.get("authType"),
                "delta_sharing_profile_name": obj.get("deltaSharingProfileName"),
                "shared_data_endpoint": obj.get("sharedDataEndpoint"),
                "token_expiration_time": obj.get("tokenExpirationTime"),
            }
        )
        return _obj



# coding: utf-8

"""
Earnix Elevate Import Export API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""


from typing import List

from pydantic.v1 import Field, StrictInt, validate_arguments
from typing_extensions import Annotated

from earnix_elevate.clients.imx.api_client import ApiClient
from earnix_elevate.clients.imx.api_response import ApiResponse
from earnix_elevate.clients.imx.exceptions import ApiTypeError
from earnix_elevate.clients.imx.models.create_data_source_request import (
    CreateDataSourceRequest,
)
from earnix_elevate.clients.imx.models.data_source_response import DataSourceResponse
from earnix_elevate.clients.imx.models.update_data_source_request import (
    UpdateDataSourceRequest,
)


class DataSourceServiceApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def create_data_source(
        self,
        create_data_source_request: Annotated[
            CreateDataSourceRequest, Field(..., description="Create DataSource Request")
        ],
        **kwargs,
    ) -> DataSourceResponse:
        """Creates a new DataSource that defines how to connect to and import data from an external system. The DataSource specifies the connection details and data location (query for databases, path for storage systems).

        :param create_data_source_request: Create DataSource Request (required)
        :type create_data_source_request: CreateDataSourceRequest
        :return: Returns the result object.
        :rtype: DataSourceResponse
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            message = "Error! Please call the create_data_source_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            raise ValueError(message)
        return self.create_data_source_with_http_info(
            create_data_source_request, **kwargs
        )

    @validate_arguments
    def create_data_source_with_http_info(
        self,
        create_data_source_request: Annotated[
            CreateDataSourceRequest, Field(..., description="Create DataSource Request")
        ],
        **kwargs,
    ) -> ApiResponse:
        """Creates a new DataSource that defines how to connect to and import data from an external system. The DataSource specifies the connection details and data location (query for databases, path for storage systems).

        :param create_data_source_request: Create DataSource Request (required)
        :type create_data_source_request: CreateDataSourceRequest
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
        :rtype: tuple(DataSourceResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["create_data_source_request"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_data_source" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params["create_data_source_request"] is not None:
            _body_params = _params["create_data_source_request"]

        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "application/problem+json"]
        )

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get(
            "_content_type",
            self.api_client.select_header_content_type(["application/json"]),
        )
        if _content_types_list:
            _header_params["Content-Type"] = _content_types_list

        # authentication setting
        _auth_settings = ["BearerAuth"]

        _response_types_map = {
            "200": "DataSourceResponse",
        }

        return self.api_client.call_api(
            "/v1/data-sources",
            "POST",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def delete_data_source(
        self,
        data_source_id: Annotated[
            StrictInt,
            Field(..., description="Unique identifier of the DataSource to operate on"),
        ],
        **kwargs,
    ) -> None:
        """Removes a DataSource from your workspace. This operation will fail if there are DataTables currently using this DataSource. Returns NOT_FOUND if the DataSource does not exist.

        :param data_source_id: Unique identifier of the DataSource to operate on (required)
        :type data_source_id: int
        :return: Returns the result object.
        :rtype: None
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            message = "Error! Please call the delete_data_source_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            raise ValueError(message)
        return self.delete_data_source_with_http_info(data_source_id, **kwargs)

    @validate_arguments
    def delete_data_source_with_http_info(
        self,
        data_source_id: Annotated[
            StrictInt,
            Field(..., description="Unique identifier of the DataSource to operate on"),
        ],
        **kwargs,
    ) -> ApiResponse:
        """Removes a DataSource from your workspace. This operation will fail if there are DataTables currently using this DataSource. Returns NOT_FOUND if the DataSource does not exist.

        :param data_source_id: Unique identifier of the DataSource to operate on (required)
        :type data_source_id: int
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
        :rtype: None
        """

        _params = locals()

        _all_params = ["data_source_id"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_data_source" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["data_source_id"] is not None:
            _path_params["data-source-id"] = _params["data_source_id"]

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/problem+json"]
        )

        # authentication setting
        _auth_settings = ["BearerAuth"]

        _response_types_map = {}

        return self.api_client.call_api(
            "/v1/data-sources/{data-source-id}",
            "DELETE",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def get_data_source(
        self,
        data_source_id: Annotated[
            StrictInt,
            Field(..., description="Unique identifier of the DataSource to operate on"),
        ],
        **kwargs,
    ) -> DataSourceResponse:
        """Retrieves detailed information about a specific DataSource including its connection configuration, data location settings, and metadata. Returns NOT_FOUND if the DataSource does not exist.

        :param data_source_id: Unique identifier of the DataSource to operate on (required)
        :type data_source_id: int
        :return: Returns the result object.
        :rtype: DataSourceResponse
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            message = "Error! Please call the get_data_source_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            raise ValueError(message)
        return self.get_data_source_with_http_info(data_source_id, **kwargs)

    @validate_arguments
    def get_data_source_with_http_info(
        self,
        data_source_id: Annotated[
            StrictInt,
            Field(..., description="Unique identifier of the DataSource to operate on"),
        ],
        **kwargs,
    ) -> ApiResponse:
        """Retrieves detailed information about a specific DataSource including its connection configuration, data location settings, and metadata. Returns NOT_FOUND if the DataSource does not exist.

        :param data_source_id: Unique identifier of the DataSource to operate on (required)
        :type data_source_id: int
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
        :rtype: tuple(DataSourceResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["data_source_id"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_data_source" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["data_source_id"] is not None:
            _path_params["data-source-id"] = _params["data_source_id"]

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "application/problem+json"]
        )

        # authentication setting
        _auth_settings = ["BearerAuth"]

        _response_types_map = {
            "200": "DataSourceResponse",
        }

        return self.api_client.call_api(
            "/v1/data-sources/{data-source-id}",
            "GET",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def list_data_sources(self, **kwargs) -> List[DataSourceResponse]:
        """Retrieves a list of all DataSources. DataSources define the configuration for importing data from external systems such as databases, cloud storage, or data lakes into the platform.
        :return: Returns the result object.
        :rtype: List[DataSourceResponse]
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            message = "Error! Please call the list_data_sources_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            raise ValueError(message)
        return self.list_data_sources_with_http_info(**kwargs)

    @validate_arguments
    def list_data_sources_with_http_info(self, **kwargs) -> ApiResponse:
        """Retrieves a list of all DataSources. DataSources define the configuration for importing data from external systems such as databases, cloud storage, or data lakes into the platform.
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
        :rtype: tuple(List[DataSourceResponse], status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = []
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_data_sources" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "application/problem+json"]
        )

        # authentication setting
        _auth_settings = ["BearerAuth"]

        _response_types_map = {
            "200": "List[DataSourceResponse]",
        }

        return self.api_client.call_api(
            "/v1/data-sources",
            "GET",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def update_data_source(
        self,
        data_source_id: Annotated[
            StrictInt,
            Field(..., description="Unique identifier of the DataSource to operate on"),
        ],
        update_data_source_request: Annotated[
            UpdateDataSourceRequest, Field(..., description="Update DataSource Request")
        ],
        **kwargs,
    ) -> DataSourceResponse:
        """Updates the configuration of an existing DataSource. This includes modifying connection settings, data location parameters, and metadata. The operation requires the current lock version to prevent concurrent modifications.

        :param data_source_id: Unique identifier of the DataSource to operate on (required)
        :type data_source_id: int
        :param update_data_source_request: Update DataSource Request (required)
        :type update_data_source_request: UpdateDataSourceRequest
        :return: Returns the result object.
        :rtype: DataSourceResponse
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            message = "Error! Please call the update_data_source_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            raise ValueError(message)
        return self.update_data_source_with_http_info(
            data_source_id, update_data_source_request, **kwargs
        )

    @validate_arguments
    def update_data_source_with_http_info(
        self,
        data_source_id: Annotated[
            StrictInt,
            Field(..., description="Unique identifier of the DataSource to operate on"),
        ],
        update_data_source_request: Annotated[
            UpdateDataSourceRequest, Field(..., description="Update DataSource Request")
        ],
        **kwargs,
    ) -> ApiResponse:
        """Updates the configuration of an existing DataSource. This includes modifying connection settings, data location parameters, and metadata. The operation requires the current lock version to prevent concurrent modifications.

        :param data_source_id: Unique identifier of the DataSource to operate on (required)
        :type data_source_id: int
        :param update_data_source_request: Update DataSource Request (required)
        :type update_data_source_request: UpdateDataSourceRequest
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
        :rtype: tuple(DataSourceResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["data_source_id", "update_data_source_request"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_data_source" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["data_source_id"] is not None:
            _path_params["data-source-id"] = _params["data_source_id"]

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params["update_data_source_request"] is not None:
            _body_params = _params["update_data_source_request"]

        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "application/problem+json"]
        )

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get(
            "_content_type",
            self.api_client.select_header_content_type(["application/json"]),
        )
        if _content_types_list:
            _header_params["Content-Type"] = _content_types_list

        # authentication setting
        _auth_settings = ["BearerAuth"]

        _response_types_map = {
            "200": "DataSourceResponse",
        }

        return self.api_client.call_api(
            "/v1/data-sources/{data-source-id}",
            "PUT",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )



"""
Utility functions and helpers for the Earnix Elevate SDK.

This module provides common utility functions, decorators, and helpers
that are used across multiple modules to reduce code duplication.
"""

import functools
import time
from typing import Any, Callable, Dict, Optional, TypeVar
from urllib.parse import urljoin

from .const import SERVER_TPL

# Type variable for generic functions
T = TypeVar("T")
F = TypeVar("F", bound=Callable[..., Any])


def build_server_url(server: str, route: str = "") -> str:
    """
    Build a complete server URL from server name and optional route.

    :param server: The server name (e.g., "dev", "production")
    :type server: str
    :param route: Optional route to append (e.g., "/api/data")
    :type route: str
    :returns: Complete server URL
    :rtype: str
    :raises ValueError: If server is not a string or route is not a string

    Example:
        >>> build_server_url("dev", "/api/data")
        'https://dev.e2.earnix.com/api/data'
    """
    # Input validation
    if not isinstance(server, str):
        raise ValueError(f"Server must be a string, got {type(server).__name__}")

    if not isinstance(route, str):
        raise ValueError(f"Route must be a string, got {type(route).__name__}")

    base_url = SERVER_TPL.format(server)
    if route:
        return urljoin(base_url, route.lstrip("/"))
    return base_url


def safe_getattr(obj: Any, attr: str, default: Any = None) -> Any:
    """
    Safely get an attribute from an object with a default value.

    :param obj: The object to get the attribute from
    :type obj: Any
    :param attr: The attribute name
    :type attr: str
    :param default: Default value if attribute doesn't exist
    :type default: Any
    :returns: The attribute value or default
    :rtype: Any
    """
    if obj is None:
        return default

    try:
        return getattr(obj, attr, default)
    except TypeError:
        return default


def create_error_context(operation: str, **kwargs: Any) -> Dict[str, Any]:
    """
    Create a standardized error context dictionary.

    This function works in conjunction with format_error_message to provide
    comprehensive error reporting with contextual information.

    :param operation: The operation that failed
    :type operation: str
    :param kwargs: Additional context key-value pairs
    :returns: Error context dictionary
    :rtype: Dict[str, Any]
    """
    context = {"operation": operation}
    context.update(kwargs)
    return context


def retry_on_exception(
    max_retries: int = 3,
    exceptions: tuple = (Exception,),
    delay: float = 1.0,
) -> Callable[[Callable[..., T]], Callable[..., T]]:
    """
    Decorator to retry a function on specific exceptions.

    :param max_retries: Maximum number of retries
    :type max_retries: int
    :param exceptions: Tuple of exceptions to catch and retry on
    :type exceptions: tuple
    :param delay: Delay between retries in seconds
    :type delay: float
    :returns: Decorated function
    :rtype: Callable
    """

    def decorator(func: Callable[..., T]) -> Callable[..., T]:
        @functools.wraps(func)
        def wrapper(*args: Any, **kwargs: Any) -> T:
            last_exception = None

            for attempt in range(max_retries + 1):
                try:
                    return func(*args, **kwargs)
                except exceptions as e:
                    last_exception = e
                    if attempt < max_retries:
                        time.sleep(delay)
                        continue
                    break

            # This should only happen if all retries failed
            if last_exception is not None:
                raise last_exception

            # This should never be reached, but satisfies type checker
            raise RuntimeError("Retry decorator failed without capturing exception")

        return wrapper

    return decorator


def format_error_message(
    base_message: str,
    context: Optional[Dict[str, Any]] = None,
    include_context: bool = True,
) -> str:
    """
    Format an error message with optional context information.

    :param base_message: The base error message
    :type base_message: str
    :param context: Optional context dictionary
    :type context: Optional[Dict[str, Any]]
    :param include_context: Whether to include context in the message
    :type include_context: bool
    :returns: Formatted error message
    :rtype: str
    """
    if not include_context or not context:
        return base_message

    context_parts = []
    for key, value in context.items():
        if value is not None:
            context_parts.append(f"{key}={value}")

    if context_parts:
        context_str = ", ".join(context_parts)
        return f"{base_message} (Context: {context_str})"

    return base_message



# coding: utf-8

"""
Earnix Elevate Import Export API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from __future__ import annotations

import json
import pprint
from importlib import import_module
from typing import TYPE_CHECKING, Optional, Union

from pydantic.v1 import BaseModel, Field, StrictStr

if TYPE_CHECKING:
    from earnix_elevate.clients.imx.models.delta_sharing_json_profile_auth_response import (
        DeltaSharingJsonProfileAuthResponse,
    )


class DeltaSharingAuthResponse(BaseModel):
    """
    `DeltaSharingAuthResponse`

    Delta Sharing connection authentication response.
    """

    auth_type: Optional[StrictStr] = Field(default=None, alias="authType")
    __properties = ["authType"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    # JSON field name that stores the object type
    __discriminator_property_name = "authType"

    # discriminator mappings
    __discriminator_value_class_map = {
        "deltasharing_json_profile": "DeltaSharingJsonProfileAuthResponse"
    }

    @classmethod
    def get_discriminator_value(cls, obj: dict) -> str:
        """Returns the discriminator value (object type) of the data"""
        discriminator_value = obj[cls.__discriminator_property_name]
        if discriminator_value:
            return cls.__discriminator_value_class_map.get(discriminator_value)
        else:
            return None

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Union[DeltaSharingJsonProfileAuthResponse]:
        """Create an instance of DeltaSharingAuthResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Union[DeltaSharingJsonProfileAuthResponse]:
        """Create an instance of DeltaSharingAuthResponse from a dict"""
        # look up the object type based on discriminator mapping
        object_type = cls.get_discriminator_value(obj)
        if object_type == "DeltaSharingJsonProfileAuthResponse":
            return import_module(
                "earnix_elevate.clients.imx.models.delta_sharing_json_profile_auth_response"
            ).DeltaSharingJsonProfileAuthResponse.from_dict(obj)
        raise ValueError(
            "DeltaSharingAuthResponse failed to lookup discriminator value from "
            + json.dumps(obj)
            + ". Discriminator property name: "
            + cls.__discriminator_property_name
            + ", mapping: "
            + json.dumps(cls.__discriminator_value_class_map)
        )



from importlib.metadata import version

# Domain configuration - Earnix Elevate service endpoints follow this pattern
DOMAIN_SUFFIX = ".e2.earnix.com"
SERVER_TPL = f"https://{{}}{DOMAIN_SUFFIX}"

PACKAGE_VERSION = version("earnix_elevate")

# User agent identifies SDK version to help with support and debugging
USER_AGENT = f"Earnix-Elevate-SDK-Python/{PACKAGE_VERSION}"

# Authentication constants - OAuth2-style bearer token authentication
AUTH_HEADER_NAME = "Authorization"
AUTH_HEADER_PREFIX = "Bearer"
AUTH_EXCHANGE_ROUTE = "/exchange-auth-code"
AUTH_EXCHANGE_METHOD = "POST"
AUTH_RESPONSE_KEY = "accessToken"
CONTENT_TYPE_JSON = "application/json"
ACCEPT_JSON = "application/json"

# JWT decode options - Skip signature verification to avoid key management complexity
JWT_DECODE_OPTIONS = {"verify_signature": False, "verify_exp": True}

# DNS compliance constants - Prevent DNS resolution failures and ensure valid URLs
DNS_LABEL_MAX_LENGTH = 63  # RFC 1035 limit prevents DNS server rejection
DNS_FQDN_MAX_LENGTH = 253  # RFC 1035 limit prevents URL construction failures

# Server name validation - Prevent injection attacks and ensure secure URL construction
DANGEROUS_PATTERNS = [
    ("{}", "template injection"),
    ("://", "protocol injection"),
    (" ", "spaces"),
    ("\t", "tabs"),
    ("\n", "newlines"),
    ("\r", "carriage returns"),
    ("%", "URL encoding"),
    ("&", "query parameters"),
    ("?", "query start"),
    ("#", "fragment"),
    ("@", "user info"),
    ("[", "IPv6 brackets"),
    ("]", "IPv6 brackets"),
    ("\\", "backslashes"),
    ("/", "forward slashes"),
    (";", "command separator"),
    ("|", "pipe"),
    ("`", "command substitution"),
    ("$", "variable expansion"),
    ("(", "command substitution"),
    (")", "command substitution"),
    ("<", "redirection"),
    (">", "redirection"),
]



# coding: utf-8

"""
Earnix Elevate Data API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from __future__ import annotations

import json
import pprint
from datetime import datetime
from typing import Optional

from pydantic.v1 import BaseModel, Field, StrictInt, StrictStr, conlist

from earnix_elevate.clients.data.models.export_s3_status_response import (
    ExportS3StatusResponse,
)


class ExportS3JobStatusResponse(BaseModel):
    """
    `ExportS3JobStatusResponse`

    Export S3 job status response
    """

    bucket: Optional[StrictStr] = Field(
        default=None,
        description="Name of the S3 bucket where the data will be exported",
    )
    key: Optional[StrictStr] = Field(
        default=None,
        description="S3 object key (path) where the exported data will be stored",
    )
    total_files: Optional[StrictInt] = Field(
        default=None,
        alias="totalFiles",
        description="Total number of files that will be created during the export process",
    )
    uploaded_files: Optional[conlist(StrictStr)] = Field(
        default=None,
        alias="uploadedFiles",
        description="List of file names that have been successfully uploaded to S3",
    )
    status: Optional[ExportS3StatusResponse] = None
    created_date: Optional[datetime] = Field(
        default=None,
        alias="createdDate",
        description="Date and time when the export job was created",
    )
    __properties = [
        "bucket",
        "key",
        "totalFiles",
        "uploadedFiles",
        "status",
        "createdDate",
    ]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ExportS3JobStatusResponse:
        """Create an instance of ExportS3JobStatusResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of status
        if self.status:
            _dict["status"] = self.status.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ExportS3JobStatusResponse:
        """Create an instance of ExportS3JobStatusResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ExportS3JobStatusResponse.parse_obj(obj)

        _obj = ExportS3JobStatusResponse.parse_obj(
            {
                "bucket": obj.get("bucket"),
                "key": obj.get("key"),
                "total_files": obj.get("totalFiles"),
                "uploaded_files": obj.get("uploadedFiles"),
                "status": ExportS3StatusResponse.from_dict(obj.get("status"))
                if obj.get("status") is not None
                else None,
                "created_date": obj.get("createdDate"),
            }
        )
        return _obj



# coding: utf-8

"""
Earnix Elevate Import Export API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from __future__ import annotations

import json
import pprint

from pydantic.v1 import Field, constr

from earnix_elevate.clients.imx.models.snowflake_auth_request import (
    SnowflakeAuthRequest,
)


class SnowflakeClientCredentialsAuthRequest(SnowflakeAuthRequest):
    """
    `SnowflakeClientCredentialsAuthRequest`

    Snowflake authentication request using OAuth2 client credentials flow, requiring token endpoint, client credentials, and connection host information.
    """

    token_url: constr(strict=True, max_length=500, min_length=3) = Field(
        default=..., alias="tokenUrl", description="The OAuth2 token endpoint URL"
    )
    client_id: constr(strict=True, max_length=500, min_length=3) = Field(
        default=..., alias="clientId", description="The OAuth2 client ID"
    )
    client_secret: constr(strict=True, max_length=500, min_length=3) = Field(
        default=..., alias="clientSecret", description="The OAuth2 client secret"
    )
    scope: constr(strict=True, max_length=500, min_length=3) = Field(
        default=..., description="The OAuth2 scope for the token request"
    )
    host: constr(strict=True, max_length=500, min_length=3) = Field(
        default=..., description="The Snowflake host/account identifier"
    )
    __properties = ["authType", "tokenUrl", "clientId", "clientSecret", "scope", "host"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SnowflakeClientCredentialsAuthRequest:
        """Create an instance of SnowflakeClientCredentialsAuthRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SnowflakeClientCredentialsAuthRequest:
        """Create an instance of SnowflakeClientCredentialsAuthRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return SnowflakeClientCredentialsAuthRequest.parse_obj(obj)

        _obj = SnowflakeClientCredentialsAuthRequest.parse_obj(
            {
                "auth_type": obj.get("authType"),
                "token_url": obj.get("tokenUrl"),
                "client_id": obj.get("clientId"),
                "client_secret": obj.get("clientSecret"),
                "scope": obj.get("scope"),
                "host": obj.get("host"),
            }
        )
        return _obj



# coding: utf-8

"""
Earnix Elevate Import Export API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""


from typing import List, Optional

from pydantic.v1 import Field, StrictInt, StrictStr, conint, validate_arguments
from typing_extensions import Annotated

from earnix_elevate.clients.imx.api_client import ApiClient
from earnix_elevate.clients.imx.api_response import ApiResponse
from earnix_elevate.clients.imx.exceptions import ApiTypeError
from earnix_elevate.clients.imx.models.browse_bucket_data_source_request import (
    BrowseBucketDataSourceRequest,
)
from earnix_elevate.clients.imx.models.browse_bucket_data_source_response import (
    BrowseBucketDataSourceResponse,
)
from earnix_elevate.clients.imx.models.connection_response import ConnectionResponse
from earnix_elevate.clients.imx.models.create_connection_request import (
    CreateConnectionRequest,
)
from earnix_elevate.clients.imx.models.merge_connection_request import (
    MergeConnectionRequest,
)
from earnix_elevate.clients.imx.models.table_details_response import (
    TableDetailsResponse,
)
from earnix_elevate.clients.imx.models.test_connection_request import (
    TestConnectionRequest,
)
from earnix_elevate.clients.imx.models.test_rdbms_data_source_request import (
    TestRDBMSDataSourceRequest,
)
from earnix_elevate.clients.imx.models.test_updated_connection_request import (
    TestUpdatedConnectionRequest,
)
from earnix_elevate.clients.imx.models.update_connection_request import (
    UpdateConnectionRequest,
)


class ConnectionServiceApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def browse_bucket_data_source(
        self,
        connection_id: Annotated[
            StrictInt,
            Field(..., description="Unique identifier of the Connection to operate on"),
        ],
        browse_bucket_data_source_request: Annotated[
            BrowseBucketDataSourceRequest,
            Field(..., description="Browse Bucket DataSource Request"),
        ],
        browse_limit: Annotated[
            Optional[conint(strict=True, le=1000, ge=1)],
            Field(
                description="Maximum number of objects to retrieve in the browse operation"
            ),
        ] = None,
        **kwargs,
    ) -> BrowseBucketDataSourceResponse:
        """Browses the contents of a bucket DataSource at the specified path, returning a list of available files and folders. This helps users explore the data structure before configuring DataSources.

        :param connection_id: Unique identifier of the Connection to operate on (required)
        :type connection_id: int
        :param browse_bucket_data_source_request: Browse Bucket DataSource Request (required)
        :type browse_bucket_data_source_request: BrowseBucketDataSourceRequest
        :param browse_limit: Maximum number of objects to retrieve in the browse operation
        :type browse_limit: int
        :return: Returns the result object.
        :rtype: BrowseBucketDataSourceResponse
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            message = "Error! Please call the browse_bucket_data_source_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            raise ValueError(message)
        return self.browse_bucket_data_source_with_http_info(
            connection_id, browse_bucket_data_source_request, browse_limit, **kwargs
        )

    @validate_arguments
    def browse_bucket_data_source_with_http_info(
        self,
        connection_id: Annotated[
            StrictInt,
            Field(..., description="Unique identifier of the Connection to operate on"),
        ],
        browse_bucket_data_source_request: Annotated[
            BrowseBucketDataSourceRequest,
            Field(..., description="Browse Bucket DataSource Request"),
        ],
        browse_limit: Annotated[
            Optional[conint(strict=True, le=1000, ge=1)],
            Field(
                description="Maximum number of objects to retrieve in the browse operation"
            ),
        ] = None,
        **kwargs,
    ) -> ApiResponse:
        """Browses the contents of a bucket DataSource at the specified path, returning a list of available files and folders. This helps users explore the data structure before configuring DataSources.

        :param connection_id: Unique identifier of the Connection to operate on (required)
        :type connection_id: int
        :param browse_bucket_data_source_request: Browse Bucket DataSource Request (required)
        :type browse_bucket_data_source_request: BrowseBucketDataSourceRequest
        :param browse_limit: Maximum number of objects to retrieve in the browse operation
        :type browse_limit: int
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
        :rtype: tuple(BrowseBucketDataSourceResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            "connection_id",
            "browse_bucket_data_source_request",
            "browse_limit",
        ]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method browse_bucket_data_source" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["connection_id"] is not None:
            _path_params["connection-id"] = _params["connection_id"]

        # process the query parameters
        _query_params = []
        if _params.get("browse_limit") is not None:
            _query_params.append(("browse-limit", _params["browse_limit"]))

        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params["browse_bucket_data_source_request"] is not None:
            _body_params = _params["browse_bucket_data_source_request"]

        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "application/problem+json"]
        )

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get(
            "_content_type",
            self.api_client.select_header_content_type(["application/json"]),
        )
        if _content_types_list:
            _header_params["Content-Type"] = _content_types_list

        # authentication setting
        _auth_settings = ["BearerAuth"]

        _response_types_map = {
            "200": "BrowseBucketDataSourceResponse",
        }

        return self.api_client.call_api(
            "/v1/connections/{connection-id}/browse-bucket-data-source",
            "POST",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def create_connection(
        self,
        create_connection_request: Annotated[
            CreateConnectionRequest, Field(..., description="Create Connection Request")
        ],
        **kwargs,
    ) -> ConnectionResponse:
        """Creates a new Connection that defines how to authenticate and connect to an external data system. Each Connection type has specific authentication requirements and configuration parameters.

        :param create_connection_request: Create Connection Request (required)
        :type create_connection_request: CreateConnectionRequest
        :return: Returns the result object.
        :rtype: ConnectionResponse
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            message = "Error! Please call the create_connection_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            raise ValueError(message)
        return self.create_connection_with_http_info(
            create_connection_request, **kwargs
        )

    @validate_arguments
    def create_connection_with_http_info(
        self,
        create_connection_request: Annotated[
            CreateConnectionRequest, Field(..., description="Create Connection Request")
        ],
        **kwargs,
    ) -> ApiResponse:
        """Creates a new Connection that defines how to authenticate and connect to an external data system. Each Connection type has specific authentication requirements and configuration parameters.

        :param create_connection_request: Create Connection Request (required)
        :type create_connection_request: CreateConnectionRequest
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
        :rtype: tuple(ConnectionResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["create_connection_request"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_connection" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params["create_connection_request"] is not None:
            _body_params = _params["create_connection_request"]

        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "application/problem+json"]
        )

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get(
            "_content_type",
            self.api_client.select_header_content_type(["application/json"]),
        )
        if _content_types_list:
            _header_params["Content-Type"] = _content_types_list

        # authentication setting
        _auth_settings = ["BearerAuth"]

        _response_types_map = {
            "200": "ConnectionResponse",
        }

        return self.api_client.call_api(
            "/v1/connections",
            "POST",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def delete_connection(
        self,
        connection_id: Annotated[
            StrictInt,
            Field(..., description="Unique identifier of the Connection to operate on"),
        ],
        **kwargs,
    ) -> None:
        """Removes a Connection from your workspace. This operation will fail if there are DataSources currently using this Connection. Returns NOT_FOUND if the Connection does not exist.

        :param connection_id: Unique identifier of the Connection to operate on (required)
        :type connection_id: int
        :return: Returns the result object.
        :rtype: None
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            message = "Error! Please call the delete_connection_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            raise ValueError(message)
        return self.delete_connection_with_http_info(connection_id, **kwargs)

    @validate_arguments
    def delete_connection_with_http_info(
        self,
        connection_id: Annotated[
            StrictInt,
            Field(..., description="Unique identifier of the Connection to operate on"),
        ],
        **kwargs,
    ) -> ApiResponse:
        """Removes a Connection from your workspace. This operation will fail if there are DataSources currently using this Connection. Returns NOT_FOUND if the Connection does not exist.

        :param connection_id: Unique identifier of the Connection to operate on (required)
        :type connection_id: int
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
        :rtype: None
        """

        _params = locals()

        _all_params = ["connection_id"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_connection" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["connection_id"] is not None:
            _path_params["connection-id"] = _params["connection_id"]

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/problem+json"]
        )

        # authentication setting
        _auth_settings = ["BearerAuth"]

        _response_types_map = {}

        return self.api_client.call_api(
            "/v1/connections/{connection-id}",
            "DELETE",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def get_connection(
        self,
        connection_id: Annotated[
            StrictInt,
            Field(..., description="Unique identifier of the Connection to operate on"),
        ],
        **kwargs,
    ) -> ConnectionResponse:
        """Retrieves detailed information about a specific Connection including its configuration, authentication details, and metadata. Returns NOT_FOUND if the Connection does not exist.

        :param connection_id: Unique identifier of the Connection to operate on (required)
        :type connection_id: int
        :return: Returns the result object.
        :rtype: ConnectionResponse
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            message = "Error! Please call the get_connection_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            raise ValueError(message)
        return self.get_connection_with_http_info(connection_id, **kwargs)

    @validate_arguments
    def get_connection_with_http_info(
        self,
        connection_id: Annotated[
            StrictInt,
            Field(..., description="Unique identifier of the Connection to operate on"),
        ],
        **kwargs,
    ) -> ApiResponse:
        """Retrieves detailed information about a specific Connection including its configuration, authentication details, and metadata. Returns NOT_FOUND if the Connection does not exist.

        :param connection_id: Unique identifier of the Connection to operate on (required)
        :type connection_id: int
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
        :rtype: tuple(ConnectionResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["connection_id"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_connection" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["connection_id"] is not None:
            _path_params["connection-id"] = _params["connection_id"]

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "application/problem+json"]
        )

        # authentication setting
        _auth_settings = ["BearerAuth"]

        _response_types_map = {
            "200": "ConnectionResponse",
        }

        return self.api_client.call_api(
            "/v1/connections/{connection-id}",
            "GET",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def is_connection_name_available(
        self,
        name: Annotated[
            StrictStr,
            Field(
                ...,
                description="The proposed name for the Connection to check for availability (case-insensitive)",
            ),
        ],
        **kwargs,
    ) -> bool:
        """Validates whether a Connection name is available for use within the current workspace. Name validation is case-insensitive. Returns true if the name can be used for creating a new Connection, false if it already exists.

        :param name: The proposed name for the Connection to check for availability (case-insensitive) (required)
        :type name: str
        :return: Returns the result object.
        :rtype: bool
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            message = "Error! Please call the is_connection_name_available_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            raise ValueError(message)
        return self.is_connection_name_available_with_http_info(name, **kwargs)

    @validate_arguments
    def is_connection_name_available_with_http_info(
        self,
        name: Annotated[
            StrictStr,
            Field(
                ...,
                description="The proposed name for the Connection to check for availability (case-insensitive)",
            ),
        ],
        **kwargs,
    ) -> ApiResponse:
        """Validates whether a Connection name is available for use within the current workspace. Name validation is case-insensitive. Returns true if the name can be used for creating a new Connection, false if it already exists.

        :param name: The proposed name for the Connection to check for availability (case-insensitive) (required)
        :type name: str
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
        :rtype: tuple(bool, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["name"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method is_connection_name_available" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["name"] is not None:
            _path_params["name"] = _params["name"]

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "application/problem+json"]
        )

        # authentication setting
        _auth_settings = ["BearerAuth"]

        _response_types_map = {
            "200": "bool",
        }

        return self.api_client.call_api(
            "/v1/connection-utils/is-name-available/{name}",
            "GET",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def list_connections(self, **kwargs) -> List[ConnectionResponse]:
        """Retrieves a list of all Connections. Connections represent the authentication and configuration details needed to connect to external data systems such as databases, cloud storage services, or data platforms.
        :return: Returns the result object.
        :rtype: List[ConnectionResponse]
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            message = "Error! Please call the list_connections_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            raise ValueError(message)
        return self.list_connections_with_http_info(**kwargs)

    @validate_arguments
    def list_connections_with_http_info(self, **kwargs) -> ApiResponse:
        """Retrieves a list of all Connections. Connections represent the authentication and configuration details needed to connect to external data systems such as databases, cloud storage services, or data platforms.
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
        :rtype: tuple(List[ConnectionResponse], status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = []
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_connections" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "application/problem+json"]
        )

        # authentication setting
        _auth_settings = ["BearerAuth"]

        _response_types_map = {
            "200": "List[ConnectionResponse]",
        }

        return self.api_client.call_api(
            "/v1/connections",
            "GET",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def list_tables(
        self,
        connection_id: Annotated[
            StrictInt,
            Field(..., description="Unique identifier of the Connection to operate on"),
        ],
        **kwargs,
    ) -> List[TableDetailsResponse]:
        """Retrieves a list of all accessible tables and views in the specified connection. Returns table metadata including database, schema, and table names for browsing available data sources.

        :param connection_id: Unique identifier of the Connection to operate on (required)
        :type connection_id: int
        :return: Returns the result object.
        :rtype: List[TableDetailsResponse]
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            message = "Error! Please call the list_tables_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            raise ValueError(message)
        return self.list_tables_with_http_info(connection_id, **kwargs)

    @validate_arguments
    def list_tables_with_http_info(
        self,
        connection_id: Annotated[
            StrictInt,
            Field(..., description="Unique identifier of the Connection to operate on"),
        ],
        **kwargs,
    ) -> ApiResponse:
        """Retrieves a list of all accessible tables and views in the specified connection. Returns table metadata including database, schema, and table names for browsing available data sources.

        :param connection_id: Unique identifier of the Connection to operate on (required)
        :type connection_id: int
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
        :rtype: tuple(List[TableDetailsResponse], status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["connection_id"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_tables" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["connection_id"] is not None:
            _path_params["connection-id"] = _params["connection_id"]

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "application/problem+json"]
        )

        # authentication setting
        _auth_settings = ["BearerAuth"]

        _response_types_map = {
            "200": "List[TableDetailsResponse]",
        }

        return self.api_client.call_api(
            "/v1/connections/{connection-id}/tables",
            "GET",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def list_warehouses(
        self,
        connection_id: Annotated[
            StrictInt,
            Field(..., description="Unique identifier of the Connection to operate on"),
        ],
        **kwargs,
    ) -> List[str]:
        """Retrieves a list of all available warehouses in a Snowflake connection. Warehouses are compute resources that can be used for query execution and data processing operations.

        :param connection_id: Unique identifier of the Connection to operate on (required)
        :type connection_id: int
        :return: Returns the result object.
        :rtype: List[str]
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            message = "Error! Please call the list_warehouses_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            raise ValueError(message)
        return self.list_warehouses_with_http_info(connection_id, **kwargs)

    @validate_arguments
    def list_warehouses_with_http_info(
        self,
        connection_id: Annotated[
            StrictInt,
            Field(..., description="Unique identifier of the Connection to operate on"),
        ],
        **kwargs,
    ) -> ApiResponse:
        """Retrieves a list of all available warehouses in a Snowflake connection. Warehouses are compute resources that can be used for query execution and data processing operations.

        :param connection_id: Unique identifier of the Connection to operate on (required)
        :type connection_id: int
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
        :rtype: tuple(List[str], status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["connection_id"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_warehouses" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["connection_id"] is not None:
            _path_params["connection-id"] = _params["connection_id"]

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "application/problem+json"]
        )

        # authentication setting
        _auth_settings = ["BearerAuth"]

        _response_types_map = {
            "200": "List[str]",
        }

        return self.api_client.call_api(
            "/v1/connections/{connection-id}/warehouses",
            "GET",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def merge_connection(
        self,
        connection_id: Annotated[
            StrictInt,
            Field(..., description="Unique identifier of the Connection to operate on"),
        ],
        merge_connection_request: Annotated[
            MergeConnectionRequest, Field(..., description="Merge Connection Request")
        ],
        **kwargs,
    ) -> ConnectionResponse:
        """Partially updates a Connection by applying only the provided fields while leaving other fields unchanged. This operation uses merge-patch semantics and requires the current lock version.

        :param connection_id: Unique identifier of the Connection to operate on (required)
        :type connection_id: int
        :param merge_connection_request: Merge Connection Request (required)
        :type merge_connection_request: MergeConnectionRequest
        :return: Returns the result object.
        :rtype: ConnectionResponse
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            message = "Error! Please call the merge_connection_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            raise ValueError(message)
        return self.merge_connection_with_http_info(
            connection_id, merge_connection_request, **kwargs
        )

    @validate_arguments
    def merge_connection_with_http_info(
        self,
        connection_id: Annotated[
            StrictInt,
            Field(..., description="Unique identifier of the Connection to operate on"),
        ],
        merge_connection_request: Annotated[
            MergeConnectionRequest, Field(..., description="Merge Connection Request")
        ],
        **kwargs,
    ) -> ApiResponse:
        """Partially updates a Connection by applying only the provided fields while leaving other fields unchanged. This operation uses merge-patch semantics and requires the current lock version.

        :param connection_id: Unique identifier of the Connection to operate on (required)
        :type connection_id: int
        :param merge_connection_request: Merge Connection Request (required)
        :type merge_connection_request: MergeConnectionRequest
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
        :rtype: tuple(ConnectionResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["connection_id", "merge_connection_request"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method merge_connection" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["connection_id"] is not None:
            _path_params["connection-id"] = _params["connection_id"]

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params["merge_connection_request"] is not None:
            _body_params = _params["merge_connection_request"]

        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "application/problem+json"]
        )

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get(
            "_content_type",
            self.api_client.select_header_content_type(
                ["application/merge-patch+json"]
            ),
        )
        if _content_types_list:
            _header_params["Content-Type"] = _content_types_list

        # authentication setting
        _auth_settings = ["BearerAuth"]

        _response_types_map = {
            "200": "ConnectionResponse",
        }

        return self.api_client.call_api(
            "/v1/connections/{connection-id}",
            "PATCH",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def test_connection(
        self,
        test_connection_request: Annotated[
            TestConnectionRequest, Field(..., description="Test Connection Request")
        ],
        **kwargs,
    ) -> None:
        """Tests a Connection configuration by attempting to establish connectivity using the provided authentication details and connection parameters. This allows validation before creating the Connection.

        :param test_connection_request: Test Connection Request (required)
        :type test_connection_request: TestConnectionRequest
        :return: Returns the result object.
        :rtype: None
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            message = "Error! Please call the test_connection_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            raise ValueError(message)
        return self.test_connection_with_http_info(test_connection_request, **kwargs)

    @validate_arguments
    def test_connection_with_http_info(
        self,
        test_connection_request: Annotated[
            TestConnectionRequest, Field(..., description="Test Connection Request")
        ],
        **kwargs,
    ) -> ApiResponse:
        """Tests a Connection configuration by attempting to establish connectivity using the provided authentication details and connection parameters. This allows validation before creating the Connection.

        :param test_connection_request: Test Connection Request (required)
        :type test_connection_request: TestConnectionRequest
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
        :rtype: None
        """

        _params = locals()

        _all_params = ["test_connection_request"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method test_connection" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params["test_connection_request"] is not None:
            _body_params = _params["test_connection_request"]

        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/problem+json"]
        )

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get(
            "_content_type",
            self.api_client.select_header_content_type(["application/json"]),
        )
        if _content_types_list:
            _header_params["Content-Type"] = _content_types_list

        # authentication setting
        _auth_settings = ["BearerAuth"]

        _response_types_map = {}

        return self.api_client.call_api(
            "/v1/test-connection",
            "POST",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def test_connection_by_id(
        self,
        connection_id: Annotated[
            StrictInt,
            Field(..., description="Unique identifier of the Connection to operate on"),
        ],
        test_updated_connection_request: Annotated[
            Optional[TestUpdatedConnectionRequest],
            Field(
                description="Test Updated Connection Request - validates connectivity using current stored configuration with optional parameter overrides"
            ),
        ] = None,
        **kwargs,
    ) -> None:
        """Tests the connectivity of an existing Connection using its current configuration. Optionally accepts updated connection parameters to test connectivity before applying changes to the Connection.

        :param connection_id: Unique identifier of the Connection to operate on (required)
        :type connection_id: int
        :param test_updated_connection_request: Test Updated Connection Request - validates connectivity using current stored configuration with optional parameter overrides
        :type test_updated_connection_request: TestUpdatedConnectionRequest
        :return: Returns the result object.
        :rtype: None
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            message = "Error! Please call the test_connection_by_id_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            raise ValueError(message)
        return self.test_connection_by_id_with_http_info(
            connection_id, test_updated_connection_request, **kwargs
        )

    @validate_arguments
    def test_connection_by_id_with_http_info(
        self,
        connection_id: Annotated[
            StrictInt,
            Field(..., description="Unique identifier of the Connection to operate on"),
        ],
        test_updated_connection_request: Annotated[
            Optional[TestUpdatedConnectionRequest],
            Field(
                description="Test Updated Connection Request - validates connectivity using current stored configuration with optional parameter overrides"
            ),
        ] = None,
        **kwargs,
    ) -> ApiResponse:
        """Tests the connectivity of an existing Connection using its current configuration. Optionally accepts updated connection parameters to test connectivity before applying changes to the Connection.

        :param connection_id: Unique identifier of the Connection to operate on (required)
        :type connection_id: int
        :param test_updated_connection_request: Test Updated Connection Request - validates connectivity using current stored configuration with optional parameter overrides
        :type test_updated_connection_request: TestUpdatedConnectionRequest
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
        :rtype: None
        """

        _params = locals()

        _all_params = ["connection_id", "test_updated_connection_request"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method test_connection_by_id" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["connection_id"] is not None:
            _path_params["connection-id"] = _params["connection_id"]

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params["test_updated_connection_request"] is not None:
            _body_params = _params["test_updated_connection_request"]

        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/problem+json"]
        )

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get(
            "_content_type",
            self.api_client.select_header_content_type(["application/json"]),
        )
        if _content_types_list:
            _header_params["Content-Type"] = _content_types_list

        # authentication setting
        _auth_settings = ["BearerAuth"]

        _response_types_map = {}

        return self.api_client.call_api(
            "/v1/connections/{connection-id}/test-connection",
            "POST",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def test_rdbms_data_source(
        self,
        connection_id: Annotated[
            StrictInt,
            Field(..., description="Unique identifier of the Connection to operate on"),
        ],
        test_rdbms_data_source_request: Annotated[
            TestRDBMSDataSourceRequest,
            Field(..., description="Test RDBMS DataSource Request"),
        ],
        **kwargs,
    ) -> None:
        """Tests an RDBMS DataSource configuration by executing the specified query to verify data accessibility and query validity. This helps validate DataSource settings before creating or updating them.

        :param connection_id: Unique identifier of the Connection to operate on (required)
        :type connection_id: int
        :param test_rdbms_data_source_request: Test RDBMS DataSource Request (required)
        :type test_rdbms_data_source_request: TestRDBMSDataSourceRequest
        :return: Returns the result object.
        :rtype: None
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            message = "Error! Please call the test_rdbms_data_source_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            raise ValueError(message)
        return self.test_rdbms_data_source_with_http_info(
            connection_id, test_rdbms_data_source_request, **kwargs
        )

    @validate_arguments
    def test_rdbms_data_source_with_http_info(
        self,
        connection_id: Annotated[
            StrictInt,
            Field(..., description="Unique identifier of the Connection to operate on"),
        ],
        test_rdbms_data_source_request: Annotated[
            TestRDBMSDataSourceRequest,
            Field(..., description="Test RDBMS DataSource Request"),
        ],
        **kwargs,
    ) -> ApiResponse:
        """Tests an RDBMS DataSource configuration by executing the specified query to verify data accessibility and query validity. This helps validate DataSource settings before creating or updating them.

        :param connection_id: Unique identifier of the Connection to operate on (required)
        :type connection_id: int
        :param test_rdbms_data_source_request: Test RDBMS DataSource Request (required)
        :type test_rdbms_data_source_request: TestRDBMSDataSourceRequest
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
        :rtype: None
        """

        _params = locals()

        _all_params = ["connection_id", "test_rdbms_data_source_request"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method test_rdbms_data_source" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["connection_id"] is not None:
            _path_params["connection-id"] = _params["connection_id"]

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params["test_rdbms_data_source_request"] is not None:
            _body_params = _params["test_rdbms_data_source_request"]

        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/problem+json"]
        )

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get(
            "_content_type",
            self.api_client.select_header_content_type(["application/json"]),
        )
        if _content_types_list:
            _header_params["Content-Type"] = _content_types_list

        # authentication setting
        _auth_settings = ["BearerAuth"]

        _response_types_map = {}

        return self.api_client.call_api(
            "/v1/connections/{connection-id}/test-rdbms-data-source",
            "POST",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def update_connection(
        self,
        connection_id: Annotated[
            StrictInt,
            Field(..., description="Unique identifier of the Connection to operate on"),
        ],
        update_connection_request: Annotated[
            UpdateConnectionRequest, Field(..., description="Update Connection Request")
        ],
        **kwargs,
    ) -> ConnectionResponse:
        """Updates the complete configuration of an existing Connection including authentication details and connection parameters. The operation requires the current lock version to prevent concurrent modifications.

        :param connection_id: Unique identifier of the Connection to operate on (required)
        :type connection_id: int
        :param update_connection_request: Update Connection Request (required)
        :type update_connection_request: UpdateConnectionRequest
        :return: Returns the result object.
        :rtype: ConnectionResponse
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            message = "Error! Please call the update_connection_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            raise ValueError(message)
        return self.update_connection_with_http_info(
            connection_id, update_connection_request, **kwargs
        )

    @validate_arguments
    def update_connection_with_http_info(
        self,
        connection_id: Annotated[
            StrictInt,
            Field(..., description="Unique identifier of the Connection to operate on"),
        ],
        update_connection_request: Annotated[
            UpdateConnectionRequest, Field(..., description="Update Connection Request")
        ],
        **kwargs,
    ) -> ApiResponse:
        """Updates the complete configuration of an existing Connection including authentication details and connection parameters. The operation requires the current lock version to prevent concurrent modifications.

        :param connection_id: Unique identifier of the Connection to operate on (required)
        :type connection_id: int
        :param update_connection_request: Update Connection Request (required)
        :type update_connection_request: UpdateConnectionRequest
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
        :rtype: tuple(ConnectionResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["connection_id", "update_connection_request"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_connection" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["connection_id"] is not None:
            _path_params["connection-id"] = _params["connection_id"]

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params["update_connection_request"] is not None:
            _body_params = _params["update_connection_request"]

        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "application/problem+json"]
        )

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get(
            "_content_type",
            self.api_client.select_header_content_type(["application/json"]),
        )
        if _content_types_list:
            _header_params["Content-Type"] = _content_types_list

        # authentication setting
        _auth_settings = ["BearerAuth"]

        _response_types_map = {
            "200": "ConnectionResponse",
        }

        return self.api_client.call_api(
            "/v1/connections/{connection-id}",
            "PUT",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )
